import json
import os

import requests

import mycloudhome.configure as configure


def login(username, password):
    token = fetch_token(username, password)
    fetch_user_info(username)
    return token


def fetch_token(username, password):
    url = configure.get('cloud.service.urls', 'service.auth0.url')+'/oauth/ro'
    payload = {
        "username": username,
        "password": password,
        "grant_type": "password",
        "scope": "openid offline_access",
        "device": "123456789",
        "connection": "Username-Password-Authentication",
        "client_id": "56pjpE1J4c6ZyATz3sYP8cMT47CZd6rk"
    }

    response = requests.post(url, data=payload)
    if configure.debug:
        print(url)
        print(payload)
        print(response.content)
    if response.status_code != 200:
        raise Exception("Login Error !!! [{}][{}]".format(
            response.status_code, response.content))

    token = json.loads(response.content)
    configure.save_token(token)
    return token


def token():
    return configure.get_token()


def fetch_user_info(username):

    url = configure.get('cloud.service.urls', 'service.auth.url') + \
        '/authservice/v2/auth0/user?email={}'
    response = requests.get(url.format(username), headers={
                            'Authorization': 'Bearer '+token()})
    if configure.debug:
        print(url.format(username))
        print(response.content)
    if response.status_code != 200:
        raise Exception("Login Error !!! [{}][{}]".format(
            response.status_code, response.content))

    user_info = json.loads(response.content)

    list(map(lambda user: configure.save_profiles(
        get_list_by_user_id(user['user_id']), user), user_info['data']))

def get_list_by_user_id(user_id):
    url = configure.get('cloud.service.urls',
                        'service.device.url')+'/device/v1/user/{}?pretty=true'
    
    response = requests.get(url.format(user_id), headers={
                            'Authorization': 'Bearer '+ token()})
    if configure.debug:
        print(url.format(user_id))                        
        print(response.content)

    if response.status_code != 200:
        raise Exception("DEVICE INFO Error !!! [{}][{}]".format(
            response.status_code, response.content))

    device_info = json.loads(response.content)
    return device_info['data']


import json
import os
from pathlib import Path

import requests

import mycloudhome.configure as configure
import mycloudhome.authorization as auth
import mycloudhome.filemanagement as filemanagement

from collections import OrderedDict
from pprint import pformat


def load_json_preserve_order(s):
    return json.loads(s, object_pairs_hook=OrderedDict)


def pretty(d: dict):
    return pformat(d)


# wd:// --> root
# wd://temp/a.txt --> some file id
def convert_wd_path_to_wd_id(wdPath):
    if wdPath == 'wd://' or wdPath == 'root':
        return 'root'
    idx = 'root'
    for name in wdPath.replace("wd://", "").split('/'):
        if name == "":
            continue
        sub_dir = filemanagement.get_file_under_dir_by_name(name, idx)
        if sub_dir is None:
            raise Exception("WD PATH Not FOUND!!! [{}]".format(name))
        idx = sub_dir['id']

    if configure.debug:
        print("Convert {} to {}".format(wdPath, idx))
    return idx


def is_wd_path(path):
    if path.startswith('wd://'):
        return True
    if path == 'root':
        return True
    return False


def is_local_dir(path):
    return Path(path).is_dir()

def is_local_file(path):
    return Path(path).is_file()

def get_local_file_name(path):
    return Path(path).name


import sys
import codecs

from setuptools import setup, find_packages

import mycloudhome

install_requires = [
    'requests',
    'click',
    'progress'
]

def long_description():
    with codecs.open('README.md', encoding='utf8') as f:
        return f.read()

setup(
    name='mycloudhome',
    version=mycloudhome.__version__,
    description=mycloudhome.__doc__.strip(),
    long_description=long_description(),
    # url='https://httpie.org/',
    # download_url=f'https://github.com/jakubroztocil/httpie/archive/{httpie.__version__}.tar.gz',
    author=mycloudhome.__author__,
    author_email='yang.lights@hotmail.com',
    license=mycloudhome.__licence__,
    packages=find_packages(),
    entry_points={
        'console_scripts': [
            'mycloudhome = mycloudhome.main:cli',
        ],
    },
    python_requires='>=3.6',
    install_requires=install_requires,
    keywords=('WD My Cloud Home','western digital','cli'),
)